@@ -1,3 +1,4 @@
 import jgo
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     jgo.main()
